--[[
Jamba - Jafula's Awesome Multi-Boxer Assistant
Copyright 2008 - 2010 Michael "Jafula" Miller
All Rights Reserved
http://wow.jafula.com/addons/jamba/
jamba at jafula dot com

this module by ronghail
jambagoldsum at jamba dot kicks-ass dot net
]]--

-- Create the addon using AceAddon-3.0 and embed some libraries.
local AJM = LibStub( "AceAddon-3.0" ):NewAddon( 
	"JambaGoldSum", 
	"JambaModule-1.0", 
	"AceConsole-3.0", 
	"AceEvent-3.0",
	"AceTimer-3.0"
)

-- Get the Jamba Utilities Library.
local JambaUtilities = LibStub:GetLibrary( "JambaUtilities-1.0" )
local JambaHelperSettings = LibStub:GetLibrary( "JambaHelperSettings-1.0" )
local LibBagUtils = LibStub:GetLibrary( "LibBagUtils-1.0" )

--  Constants and Locale for this module.
AJM.moduleName = "Jamba-GoldSum"
AJM.settingsDatabaseName = "JambaToonGoldSumDB"
AJM.chatCommand = "jamba-goldsum"
local L = LibStub( "AceLocale-3.0" ):GetLocale( AJM.moduleName )
AJM.parentDisplayName = L["GoldSum"]
--AJM.parentDisplayNameToon = L["Toon"]
--AJM.parentDisplayNameMerchant = L["Merchant"]
AJM.moduleDisplayName = L["GoldSum"]

-- Jamba key bindings.
BINDING_HEADER_JAMBAGOLDSUM = L["Jamba-Gold-Sum"]
BINDING_NAME_JAMBAGOLDSUM1 = L["Show Gold Sum"]

-- Settings - the values to store and their defaults for the settings database.
AJM.settings = {
	profile = {
		showGoldSum = true,
		showToonGold = true,
		messageArea = JambaApi.DefaultMessageArea(),
	},
}

-- Configuration.
function AJM:GetConfiguration()
	local configuration = {
		name = AJM.moduleDisplayName,
		handler = AJM,
		type = 'group',
		-- next 3 lines necessary?
		childGroups = "tab",
		get = "JambaConfigurationGetSetting",
		set = "JambaConfigurationSetSetting",
		args = {	
			push = {
				type = "input",
				name = L["Push Settings"],
				desc = L["Push the GoldSum settings to all characters in the team."],
				usage = "/jamba-goldsum push",
				get = false,
				set = "JambaSendSettings",
			},
			send = {
				type = "input",
				name = L["Show Team Gold"],
				desc = L["Show team gold."],
				usage = "/jamba-goldsum send",
				get = false,
				set = "SendToonGoldCommand",
			},											
		},
	}
	return configuration
end

local function DebugMessage( ... )
	AJM:Print( ... )
end

-------------------------------------------------------------------------------------------------------------
-- Command this module sends.
-------------------------------------------------------------------------------------------------------------
AJM.COMMAND_SEND_TOON_GOLD = "SendToonGold"
AJM.COMMAND_TOTAL_TOON_GOLD = "TotalToonGold"


-------------------------------------------------------------------------------------------------------------
-- Messages module sends.
-------------------------------------------------------------------------------------------------------------

-------------------------------------------------------------------------------------------------------------
-- Settings Dialogs.
-------------------------------------------------------------------------------------------------------------


local function SettingsCreateGoldSum( top )
	-- Get positions.
	local checkBoxHeight = JambaHelperSettings:GetCheckBoxHeight()
	local editBoxHeight = JambaHelperSettings:GetEditBoxHeight()
	local dropdownHeight = JambaHelperSettings:GetDropdownHeight()
	local labelHeight = JambaHelperSettings:GetLabelHeight()
	local left = JambaHelperSettings:LeftOfSettings()
	local headingHeight = JambaHelperSettings:HeadingHeight()
	local headingWidth = JambaHelperSettings:HeadingWidth( false )
	local horizontalSpacing = JambaHelperSettings:GetHorizontalSpacing()
	local verticalSpacing = JambaHelperSettings:GetVerticalSpacing()
	local halfWidth = (headingWidth - horizontalSpacing) / 2
	local thirdWidth = (headingWidth - (horizontalSpacing * 2)) / 3
	local column2left = left + halfWidth
	local left2 = left + thirdWidth
	local left3 = left + (thirdWidth * 2)
	local movingTop = top
	JambaHelperSettings:CreateHeading( AJM.settingsControlGoldSum, L["GoldSum"], movingTop, false )
	movingTop = movingTop - headingHeight
	AJM.settingsControlGoldSum.checkBoxShowGoldSum = JambaHelperSettings:CreateCheckBox( 
		AJM.settingsControlGoldSum, 
		headingWidth, 
		left, 
		movingTop, 
		L["Show Gold Sum"],
		AJM.SettingsToggleShowGoldSum
	)	
	movingTop = movingTop - checkBoxHeight
	AJM.settingsControlGoldSum.checkBoxShowToonGold = JambaHelperSettings:CreateCheckBox( 
		AJM.settingsControlGoldSum, 
		headingWidth, 
		left, 
		movingTop, 
		L["Show Toon Gold"],
		AJM.SettingsToggleShowToonGold
	)	
	movingTop = movingTop - dropdownHeight - verticalSpacing			
	return movingTop	
end

local function SettingsCreate()
	AJM.settingsControlGoldSum = {}
	JambaHelperSettings:CreateSettings( 
		AJM.settingsControlGoldSum, 
		--L["Toon"]..L[": "]..L["GoldSum"], 
		AJM.moduleDisplayName, 
		AJM.parentDisplayName, 
		--AJM.parentDisplayNameToon, 
		AJM.SettingsPushSettingsClick 
	)
	local bottomOfGoldSum = SettingsCreateGoldSum( JambaHelperSettings:TopOfSettings() )
	AJM.settingsControlGoldSum.widgetSettings.content:SetHeight( -bottomOfGoldSum )
	-- Help
	local helpTable = {}
	JambaHelperSettings:CreateHelp( AJM.settingsControlGoldSum, helpTable, AJM:GetConfiguration() )		
end

-------------------------------------------------------------------------------------------------------------
-- Settings Populate.
-------------------------------------------------------------------------------------------------------------

function AJM:BeforeJambaProfileChanged()	
end

function AJM:OnJambaProfileChanged()	
	AJM:SettingsRefresh()
end

function AJM:SettingsRefresh()
	AJM.settingsControlGoldSum.checkBoxShowGoldSum:SetValue( AJM.db.showGoldSum )
	AJM.settingsControlGoldSum.checkBoxShowToonGold:SetValue( AJM.db.showToonGold )
end

function AJM:SettingsPushSettingsClick( event )
	AJM:JambaSendSettings()
end

function AJM:SettingsToggleShowGoldSum( event, checked )
	AJM.db.showGoldSum = checked
	AJM:SettingsRefresh()
end

function AJM:SettingsToggleShowToonGold( event, checked )
	AJM.db.showToonGold = checked
	AJM:SettingsRefresh()
end


-------------------------------------------------------------------------------------------------------------
-- Addon initialization, enabling and disabling.
-------------------------------------------------------------------------------------------------------------

-- Initialise the module.
function AJM:OnInitialize()
	-- Create the settings control.
	SettingsCreate()
	-- Initialise the JambaModule part of this module.
	AJM:JambaModuleInitialize( AJM.settingsControlGoldSum.widgetSettings.frame )
	-- Populate the settings.
	AJM:SettingsRefresh()	
	-- Key bindings.
	JambaTeamSecureButtonGoldSum = CreateFrame( "CheckButton", "JambaTeamSecureButtonGoldSum", nil, "SecureActionButtonTemplate" )
	JambaTeamSecureButtonGoldSum:SetAttribute( "type", "macro" )
	JambaTeamSecureButtonGoldSum:SetAttribute( "macrotext", "/jamba-goldsum send" )
	JambaTeamSecureButtonGoldSum:Hide()	

end

-- Called when the addon is enabled.
function AJM:OnEnable()
	-- Initialize key bindings.
	AJM.keyBindingFrame = CreateFrame( "Frame", nil, UIParent )
	AJM:RegisterEvent( "UPDATE_BINDINGS" )
	AJM:UPDATE_BINDINGS()
end

-- Called when the addon is disabled.
function AJM:OnDisable()
end

-- Settings received.
function AJM:JambaOnSettingsReceived( characterName, settings )	
	if characterName ~= AJM.characterName then
		-- Update the settings.
		AJM.db.showGoldSum = settings.showGoldSum
		AJM.db.showToonGold = settings.showToonGold
		AJM.db.messageArea = settings.messageArea
		-- Refresh the settings.
		AJM:SettingsRefresh()
		-- Tell the player.
		AJM:Print( L["Settings received from A."]( characterName ) )
	end
end

function AJM:UPDATE_BINDINGS()
	if InCombatLockdown() then
		return
	end
	ClearOverrideBindings( AJM.keyBindingFrame )
	local key1, key2 = GetBindingKey( "JAMBAGOLDSUM1" )		
	if key1 then 
		DebugMessage("should be setting up keybinding here")
		SetOverrideBindingClick( AJM.keyBindingFrame, false, key1, "JambaTeamSecureButtonGoldSum" ) 
	end
	if key2 then 
		SetOverrideBindingClick( AJM.keyBindingFrame, false, key2, "JambaTeamSecureButtonGoldSum" ) 
	end	
end

function AJM:SendToonGoldCommand( info, parameters )
	local tag = parameters
	AJM:SendToonGoldSendCommand( tag )
end

function AJM:SendToonGoldSendCommand( tag )
	AJM:JambaSendCommandToTeam( AJM.COMMAND_SEND_TOON_GOLD, tag )
end

function AJM:SendToonGold( info, parameters )
	local toonMoney = GetMoney( ) / 10000
	if AJM.db.showToonGold then
		-- I am not sure how to just simply print this out so I am using this for now
		AJM:JambaSendMessageToTeam( AJM.db.messageArea, L["A has X gold."]( AJM.characterName, toonMoney ) )
	end
	AJM:JambaSendCommandToTeam( AJM.COMMAND_TOTAL_TOON_GOLD, toonMoney )
end

function AJM:ReceiveCommandSendToonGold( tag )
	-- DebugMessage("in receive commandsendtoongold")
	AJM:SendToonGold( tag )
end

function AJM:ReceiveCommandTotalToonGold( tag )
	-- DebugMessage("in total commandsendtoongold")
	AJM:TotalToonGold( tag )
end

local TotalToonMoney = 0
local TotalToonMoneyCount = 0
function AJM:TotalToonGold( tag )
	-- good stuff goes here
	TotalToonMoney = TotalToonMoney + tag
	TotalToonMoneyCount = TotalToonMoneyCount + 1
	if TotalToonMoneyCount > GetNumPartyMembers() then
		if JambaApi.GetMasterName() == AJM.characterName then
			if AJM.db.showGoldSum then
				-- I am not sure how to just simply print this out so I am using this for now
				AJM:JambaSendMessageToTeam( AJM.db.messageArea, L["Team gold sum is X."]( TotalToonMoney ) )
			end
		end
		TotalToonMoney = 0
		TotalToonMoneyCount = 0
	end
end

-- A Jamba command has been received.
function AJM:JambaOnCommandReceived( characterName, commandName, ... )
	if commandName == AJM.COMMAND_SEND_TOON_GOLD then
		AJM:ReceiveCommandSendToonGold( ... )
	end
	if commandName == AJM.COMMAND_TOTAL_TOON_GOLD then
		AJM:ReceiveCommandTotalToonGold( ... )
	end
end
--
-- db.com is way overmoderated by control freaks
